==> compile-vue-sfc-0.0.7.tgz: package/utils/compile.js <==
import vue from '@vitejs/plugin-vue';
import { execa } from 'execa';
import { findUp } from 'find-up';
import { globby } from 'globby';
import * as fs from 'node:fs';
import { createRequire } from 'node:module';
import * as path from 'node:path';
import process from 'node:process';
import { rollup } from 'rollup';
import styles from 'rollup-plugin-styles';
import tmp from 'tmp-promise';
import { readFile as readTsconfigFile } from 'tsconfig';
const __require = createRequire(import.meta.url);
const randomChars = () => Math.random().toString(36).slice(2);
export async function compileVueSFC(options) {
    const payload = {
        outputChunks: [],
    };
    const vueSFCFiles = await globby(options.files);
    if (vueSFCFiles.length === 0) {
        throw new Error('No files were provided.');
    }
    if (options.declarations) {
        // To generate the declarations, we need to create a temporary tsconfig.json file to pass to vue-tsc. Unfortunately, TypeScript doesn't support specifying individual files yet, so we instead symlink all the project files into a temporary directory.
        let tsconfigPath;
        if (options.tsconfigPath === undefined) {
            const projectTsconfigPath = await findUp('tsconfig.json', {
                cwd: path.dirname(vueSFCFiles[0]),
            });
            if (projectTsconfigPath === undefined) {
                throw new Error('`tsconfig.json` file not found');
            }
            tsconfigPath = projectTsconfigPath;
        }
        else {
            tsconfigPath = options.tsconfigPath;
        }
        const projectPath = options.projectRootPath ?? path.dirname(tsconfigPath);
        const tmpDir = await tmp.dir();
        const projectTmpDir = path.join(tmpDir.path, path.basename(projectPath));
        await fs.promises.symlink(projectPath, projectTmpDir);
        const declarations = [];
        const tsconfig = (await readTsconfigFile(tsconfigPath));
        const tmpTsconfigPath = path.join(projectTmpDir, `tsconfig.${randomChars()}.json`);
        const tmpOutDir = await tmp.dir();
        const tmpTsconfig = {
            ...tsconfig,
            compilerOptions: {
                ...tsconfig.compilerOptions,
                skipLibCheck: true,
                noEmitOnError: false,
                outDir: tmpOutDir.path,
                rootDir: projectPath,
                baseUrl: projectPath,
            },
            files: vueSFCFiles,
            include: [],
        };
        fs.writeFileSync(tmpTsconfigPath, JSON.stringify(tmpTsconfig, null, '\t'));
        // @ts-expect-error: We're temporarily overriding process.exit to prevent vue-tsc from exiting the program
        process.exit = (code) => {
            if (code !== 0) {
                throw new Error(`vue-tsc returned a non-zero exit code: ${code}`);
            }
            /* noop */
        };
        const vueTscPath = __require.resolve('vue-tsc/bin/vue-tsc.js');
        await execa(vueTscPath, ['--declaration', '--emitDeclarationOnly', '--project', tmpTsconfigPath], { stdio: 'inherit' });
        // Copying the declaration files to the original project
        await Promise.all(vueSFCFiles.map(async (vueSFCFilePath) => {
            const relativePath = path.relative(path.dirname(tsconfigPath), vueSFCFilePath);
            const tmpVueSFCDtsFilePath = path.join(tmpOutDir.path, `${relativePath}.d.ts`);
            const vueSFCDtsPath = path.join(projectPath, `${relativePath}.d.ts`);
            if (options.write) {
                await fs.promises.cp(tmpVueSFCDtsFilePath, vueSFCDtsPath);
            }
            declarations.push(await fs.promises.readFile(tmpVueSFCDtsFilePath, 'utf8'));
        }));
        payload.declarations = declarations;
    }
    // Transform the .vue files into JavaScript with rollup
    const outputChunks = await Promise.all(vueSFCFiles.map(async (vueSFCFile) => {
        const bundle = await rollup({
            plugins: [vue({ reactivityTransform: true }), styles()],
            external(id) {
                // TODO: find a better way to distinguish between a project's import and a rollup plugin's import
                if (id.startsWith('plugin-vue') ||
                    id.startsWith('./plugin-vue') ||
                    id.includes('/rollup-plugin-styles/') ||
                    id.includes('?')) {
                    return false;
                }
                return true;
            },
            input: vueSFCFile,
        });
        const result = await bundle.generate({ format: 'esm' });
        const { code } = result.output[0];
        if (options.write) {
            await fs.promises.writeFile(path.join(path.dirname(vueSFCFile), `${path.basename(vueSFCFile)}.js`), code);
        }
        return result.output[0];
    }));
    payload.outputChunks = outputChunks;
    return payload;
}

==> compile-vue-sfc-0.0.8.tgz: package/utils/compile.js <==
import vue from '@vitejs/plugin-vue';
import { execa } from 'execa';
import { findUp } from 'find-up';
import { globby } from 'globby';
import * as fs from 'node:fs';
import { createRequire } from 'node:module';
import * as path from 'node:path';
import process from 'node:process';
import { rollup } from 'rollup';
import styles from 'rollup-plugin-styles';
import tmp from 'tmp-promise';
import { readFile as readTsconfigFile } from 'tsconfig';
const __require = createRequire(import.meta.url);
const randomChars = () => Math.random().toString(36).slice(2);
export async function compileVueSFC(options) {
    const payload = {
        outputChunks: [],
    };
    const vueSFCFiles = await globby(options.files);
    if (vueSFCFiles.length === 0) {
        throw new Error('No files were provided.');
    }
    if (options.declarations) {
        // To generate the declarations, we need to create a temporary tsconfig.json file to pass to vue-tsc. Unfortunately, TypeScript doesn't support specifying individual files yet, so we instead symlink all the project files into a temporary directory.
        let tsconfigPath;
        if (options.tsconfigPath === undefined) {
            const projectTsconfigPath = await findUp('tsconfig.json', {
                cwd: path.dirname(vueSFCFiles[0]),
            });
            if (projectTsconfigPath === undefined) {
                throw new Error('`tsconfig.json` file not found');
            }
            tsconfigPath = projectTsconfigPath;
        }
        else {
            tsconfigPath = options.tsconfigPath;
        }
        const projectPath = options.projectRootPath ?? path.dirname(tsconfigPath);
        const tmpDir = await tmp.dir();
        const projectTmpDir = tmpDir.path;
        // Symlink the files individually and not the entire project folder so that when we create the temporary tsconfig.json file, it doesn't pollute the original directory
        const projectFiles = await fs.promises.readdir(projectPath);
        await Promise.all(projectFiles.map(async (projectFile) => {
            const projectFilePath = path.join(projectPath, projectFile);
            await fs.promises.symlink(projectFilePath, path.join(projectTmpDir, projectFile));
        }));
        const declarations = [];
        const tsconfig = (await readTsconfigFile(tsconfigPath));
        const tmpTsconfigPath = path.join(projectTmpDir, `tsconfig.${randomChars()}.json`);
        const tmpOutDir = await tmp.dir();
        const tmpTsconfig = {
            ...tsconfig,
            compilerOptions: {
                ...tsconfig.compilerOptions,
                skipLibCheck: true,
                noEmitOnError: false,
                outDir: tmpOutDir.path,
                rootDir: projectPath,
                baseUrl: projectPath,
            },
            files: vueSFCFiles,
            include: [],
        };
        fs.writeFileSync(tmpTsconfigPath, JSON.stringify(tmpTsconfig, null, '\t'));
        // @ts-expect-error: We're temporarily overriding process.exit to prevent vue-tsc from exiting the program
        process.exit = (code) => {
            if (code !== 0) {
                throw new Error(`vue-tsc returned a non-zero exit code: ${code}`);
            }
            /* noop */
        };
        const vueTscPath = __require.resolve('vue-tsc/bin/vue-tsc.js');
        await execa(vueTscPath, ['--declaration', '--emitDeclarationOnly', '--project', tmpTsconfigPath], { stdio: 'inherit' });
        // Copying the declaration files to the original project
        await Promise.all(vueSFCFiles.map(async (vueSFCFilePath) => {
            const relativePath = path.relative(path.dirname(tsconfigPath), vueSFCFilePath);
            const tmpVueSFCDtsFilePath = path.join(tmpOutDir.path, `${relativePath}.d.ts`);
            const vueSFCDtsPath = path.join(projectPath, `${relativePath}.d.ts`);
            if (options.write) {
                await fs.promises.cp(tmpVueSFCDtsFilePath, vueSFCDtsPath);
            }
            declarations.push(await fs.promises.readFile(tmpVueSFCDtsFilePath, 'utf8'));
        }));
        payload.declarations = declarations;
    }
    // Transform the .vue files into JavaScript with rollup
    const outputChunks = await Promise.all(vueSFCFiles.map(async (vueSFCFile) => {
        const bundle = await rollup({
            plugins: [vue({ reactivityTransform: true }), styles()],
            external(id) {
                // TODO: find a better way to distinguish between a project's import and a rollup plugin's import
                if (id.startsWith('plugin-vue') ||
                    id.startsWith('./plugin-vue') ||
                    id.includes('/rollup-plugin-styles/') ||
                    id.includes('?')) {
                    return false;
                }
                return true;
            },
            input: vueSFCFile,
        });
        const result = await bundle.generate({ format: 'esm' });
        const { code } = result.output[0];
        if (options.write) {
            await fs.promises.writeFile(path.join(path.dirname(vueSFCFile), `${path.basename(vueSFCFile)}.js`), code);
        }
        return result.output[0];
    }));
    payload.outputChunks = outputChunks;
    return payload;
}
